ShellSessionService

Struct ShellSessionService 

pub struct ShellSessionService { /* private fields */ }
Service for managing interactive shell sessions

Implementations

Source

impl ShellSessionService

pub fn new() -> Self

Create a new shell session service with its own registry

pub fn global() -> Self

Create a new shell session service using the global registry

pub async fn create( &self, args: ShellSessionCreateArgs, ) -> Result<ShellSessionCreateResult, ServiceError>

Create a new interactive shell session

pub async fn write( &self, args: ShellSessionWriteArgs, ) -> Result<ShellSessionWriteResult, ServiceError>

Write input to a session

pub async fn read( &self, args: ShellSessionReadArgs, ) -> Result<ShellSessionReadResult, ServiceError>

Read output from a session

pub async fn list( &self, args: ShellSessionListArgs, ) -> Result<ShellSessionListResult, ServiceError>

List sessions

pub async fn reconnect( &self, args: ShellSessionReconnectArgs, ) -> Result<ShellSessionReconnectResult, ServiceError>

Reconnect to a disconnected session

pub async fn resize( &self, args: ShellSessionResizeArgs, ) -> Result<ShellSessionResizeResult, ServiceError>

Resize a session’s terminal

pub async fn close( &self, args: ShellSessionCloseArgs, ) -> Result<ShellSessionCloseResult, ServiceError>

Close a session